==> webcamoid-debug-9.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/webcamoid/webcamoid-9.1.0/libAvKys/Plugins/MatrixTransform/MatrixTransform_autogen/EWIEGA46WW/qrc_MatrixTransform.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.9
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/webcamoid/src/webcamoid-9.1.0/libAvKys/Plugins/MatrixTransform/share/qml/main.qml
  0x0,0x0,0x3,0xa3,
  0x0,
  0x0,0xd,0xe9,0x78,0x9c,0xd5,0x54,0x5d,0x93,0xda,0x36,0x14,0x7d,0xf7,0xaf,0xb8,
  0x93,0x27,0x48,0x89,0xcd,0x47,0xb6,0xf,0x4e,0xda,0xe,0x61,0x60,0xc3,0x94,0xfd,
  0x88,0x61,0xbb,0x65,0x92,0x4c,0x47,0xd8,0x17,0xac,0x59,0x23,0x39,0x92,0xc,0x38,
  0xcd,0xfe,0xf7,0x5e,0xd9,0x8b,0x17,0x36,0x3b,0x69,0xcb,0xc,0xf,0xe8,0xc1,0x63,
  0x49,0xf7,0x1e,0x9d,0x7b,0xce,0x95,0xbc,0x97,0x70,0x8b,0xb3,0x90,0x2d,0x25,0x8f,
  0x1a,0xb0,0x2e,0x7e,0x21,0x64,0xa9,0xc9,0x14,0x2,0x4b,0xd3,0x84,0x87,0xcc,0x70,
  0x29,0x5c,0x7,0x5e,0x42,0x4f,0xa6,0xb9,0xe2,0x8b,0xd8,0x40,0xad,0x57,0x87,0x76,
  0xb3,0xf5,0x33,0xc0,0xb9,0x14,0x5f,0x59,0x22,0xa1,0xbf,0xc1,0x2f,0x19,0xc7,0x4,
  0xae,0x31,0x92,0x2,0x29,0xdc,0x66,0x54,0xd8,0xc0,0x35,0xcc,0x15,0x22,0x68,0x39,
  0x37,0x6b,0xa6,0xd0,0x87,0x5c,0x66,0x74,0x92,0x0,0x85,0x11,0xd7,0x46,0xf1,0x59,
  0x66,0x10,0xb8,0x1,0x26,0x22,0x4f,0x2a,0x58,0xca,0x88,0xcf,0x73,0xb,0x42,0x6b,
  0x99,0x88,0x50,0x81,0x89,0x11,0xc,0xaa,0xa5,0x6,0x39,0x2f,0x26,0xe7,0x97,0x37,
  0x70,0x8e,0x2,0x15,0xa3,0x73,0xb3,0x19,0x91,0x85,0x11,0xf,0x51,0x68,0xe2,0xae,
  0x21,0xb5,0x2b,0x3a,0xc6,0x8,0x66,0x5,0x8e,0xcd,0x18,0x58,0xe,0xe3,0x7,0xe,
  0x30,0x90,0x4,0x5c,0xd4,0xd7,0x0,0xe4,0xb4,0xaf,0x60,0x85,0x4a,0xd3,0x1c,0x3a,
  0xdb,0x33,0x1e,0x0,0x1b,0x20,0x95,0x5,0xa9,0x31,0x63,0x99,0x2b,0x90,0xa9,0xcd,
  0xab,0x13,0xdd,0x1c,0x12,0x66,0x1e,0x53,0xdd,0xe7,0x6a,0x7f,0x2c,0x91,0xa6,0xa2,
  0x0,0x8e,0x65,0x4a,0xe5,0xc4,0x84,0x47,0x5,0xae,0x79,0x92,0xc0,0xc,0x21,0xd3,
  0x38,0xcf,0x92,0x86,0xcd,0xa7,0x60,0xb8,0x1d,0x4e,0xde,0x5f,0xdd,0x4c,0xa0,0x7b,
  0x39,0x85,0xdb,0x6e,0x10,0x74,0x2f,0x27,0xd3,0x37,0x14,0x6c,0x62,0x49,0xbb,0xb8,
  0xc2,0x12,0x8a,0x2f,0xc9,0x28,0x42,0xa6,0xa2,0x14,0x13,0x26,0x27,0xee,0x16,0xe1,
  0xa2,0x1f,0xf4,0xde,0x53,0x4a,0xf7,0xdd,0x70,0x34,0x9c,0x4c,0xa9,0x2,0x18,0xc,
  0x27,0x97,0xfd,0xf1,0x18,0x6,0x57,0x1,0x74,0xe1,0xba,0x1b,0x4c,0x86,0xbd,0x9b,
  0x51,0x37,0x80,0xeb,0x9b,0xe0,0xfa,0x6a,0xdc,0x77,0x1,0xc6,0x68,0x69,0x59,0x7,
  0x7f,0xa4,0xef,0xbc,0xb0,0x88,0x34,0x8c,0xd0,0x30,0x9e,0xe8,0x6d,0xd5,0x53,0x72,
  0x55,0x13,0xbb,0x24,0x82,0x98,0xad,0x90,0xdc,0xd,0x91,0xaf,0x88,0x1b,0x83,0x90,
  0xda,0xe7,0xdf,0x9d,0xb3,0x20,0xd4,0x50,0x62,0x51,0x94,0xf9,0xa8,0xa2,0xb,0xc3,
  0x39,0x8,0x69,0x1a,0xa0,0x89,0xe0,0xdb,0xd8,0x98,0xd4,0xf7,0xbc,0xf5,0x7a,0xed,
  0x2e,0x44,0xe6,0x4a,0xb5,0xf0,0x92,0x12,0x40,0x7b,0xbf,0xee,0x58,0xf0,0x6a,0xcc,
  0xd,0x35,0xdb,0x36,0xbc,0x42,0x5b,0x10,0x78,0x36,0x73,0xb9,0xf4,0x28,0xd0,0x73,
  0x1c,0x92,0x50,0x2a,0x3,0x1f,0xcc,0x87,0x8c,0x87,0x77,0xd0,0x76,0x5b,0xed,0x27,
  0x6b,0x6e,0x4f,0xa,0xa3,0x64,0xa2,0x69,0xf3,0xec,0xe9,0xde,0x88,0x51,0x53,0x18,
  0xd,0x2d,0xb7,0xe3,0x38,0x3d,0x99,0x64,0x4b,0x51,0x2e,0xc1,0xdf,0xe,0xd0,0x48,
  0x15,0xb9,0xad,0xc8,0x19,0x2e,0xc,0x84,0x98,0x24,0x63,0xfe,0x95,0x68,0x9d,0x35,
  0x9d,0x62,0x7b,0x9e,0x89,0xd0,0xb6,0x13,0x64,0x29,0xf5,0x23,0xfe,0x8e,0x4a,0x60,
  0x52,0xe3,0xd4,0xf5,0x9b,0x6,0xac,0x58,0x92,0x61,0xbd,0x88,0x2b,0xc1,0xec,0x58,
  0x31,0x5,0x77,0x45,0x18,0xfc,0x2,0x17,0x8c,0x9a,0x6b,0x33,0x21,0xef,0x35,0xf9,
  0xb2,0x74,0xcb,0x8d,0x2a,0xb6,0x9c,0x7e,0x2c,0xe0,0x3e,0x53,0x78,0x1,0x58,0xed,
  0x3e,0x9f,0x4c,0x61,0x3b,0x28,0xf7,0x25,0xcd,0x11,0x9b,0xd1,0xce,0x23,0x9,0xcf,
  0x2b,0x95,0xd5,0x24,0x2d,0xa,0x77,0xcd,0xef,0x78,0x4a,0xb7,0x99,0x15,0x76,0xd8,
  0x99,0x57,0xc1,0x16,0xb7,0xec,0xaf,0x65,0x71,0x56,0x95,0x6f,0x70,0x63,0x7c,0xf8,
  0xa2,0x27,0xaa,0xf6,0xa2,0x8a,0x84,0x32,0xe8,0x45,0xfd,0xe1,0x64,0xfb,0x3d,0x57,
  0x3c,0xda,0xd3,0xd3,0x8e,0xb0,0x90,0x59,0xfb,0xd0,0x71,0x76,0x18,0xc1,0x9f,0xc0,
  0x36,0x5c,0x57,0x2b,0x13,0x3a,0x63,0x40,0xf,0x53,0xb4,0x93,0x69,0x7,0x8f,0x7c,
  0xd8,0x6c,0xf6,0x96,0xca,0x13,0xdc,0x54,0xe1,0x1c,0x15,0x3d,0x4b,0xb7,0x3c,0x32,
  0xb1,0x5f,0xd9,0xb5,0x17,0x5b,0x52,0x7f,0x5e,0xbb,0x8f,0xcd,0xcf,0x7b,0xb1,0x1a,
  0x13,0xc,0xcd,0xbb,0xfc,0x42,0xd2,0xf5,0xf6,0xc1,0xa8,0x6c,0x1f,0x8b,0xfc,0xe0,
  0x64,0xbb,0x54,0x3e,0x4,0xb8,0xe8,0x6f,0xd2,0x3f,0xb6,0xb,0x4f,0x38,0xdb,0xa1,
  0x8a,0x8,0x1f,0xbc,0x57,0xbf,0xd5,0x3e,0x45,0x3f,0x7d,0x72,0xe9,0xf3,0xad,0xf8,
  0xf9,0x56,0xfd,0xd7,0xbd,0xbd,0xb4,0xfb,0xbd,0x59,0x37,0xc,0x51,0x6b,0x3e,0x4b,
  0xd0,0x15,0x6c,0x89,0x5b,0xfd,0xcb,0xa6,0x85,0x66,0x3,0x2,0xb9,0x86,0x26,0xc9,
  0xbf,0x97,0x25,0x85,0x15,0xb2,0x17,0x33,0xb1,0x40,0x52,0x6e,0xaf,0x4f,0x29,0xc7,
  0xca,0x51,0x77,0xbe,0x3f,0xf0,0x87,0xea,0xe7,0xc7,0x51,0xbf,0x75,0xba,0xea,0xb7,
  0xe,0x50,0xbf,0x75,0xa0,0xfa,0xcd,0xe3,0xa8,0xdf,0x3e,0x5d,0xf5,0xdb,0x7,0xa8,
  0xdf,0xfe,0x5e,0xfd,0xdd,0xc7,0x68,0xfa,0xdf,0x1f,0xa3,0xfc,0x48,0x8f,0x51,0xe7,
  0x74,0xd,0x79,0x78,0x8c,0x5a,0xff,0xc7,0x90,0xce,0x61,0xd7,0x21,0x3f,0xd2,0x63,
  0xf4,0xfa,0x74,0xd5,0x6f,0x1d,0xa0,0xfe,0xeb,0x3,0xd5,0x3f,0xd2,0x63,0x74,0x76,
  0xba,0xea,0xb7,0xf,0x50,0xff,0xec,0x79,0xf5,0xef,0x9d,0x7b,0xe7,0x1f,0x8b,0xd,
  0xfe,0xda,
  
};

static const unsigned char qt_resource_name[] = {
  // MatrixTransform
  0x0,0xf,
  0x3,0x79,0x2f,0xad,
  0x0,0x4d,
  0x0,0x61,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x78,0x0,0x54,0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,0x6d,
    // share
  0x0,0x5,
  0x0,0x79,0xe8,0x85,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // main.qml
  0x0,0x8,
  0x8,0x1,0x5a,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/MatrixTransform
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/MatrixTransform/share
  0x0,0x0,0x0,0x24,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/MatrixTransform/share/qml
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/MatrixTransform/share/qml/main.qml
  0x0,0x0,0x0,0x40,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)(); }
   } dummy;
}

==> webcamoid-debug-9.1.1-2-x86_64.pkg.tar.zst: usr/src/debug/webcamoid/webcamoid-9.1.1/libAvKys/Plugins/MatrixTransform/MatrixTransform_autogen/EWIEGA46WW/qrc_MatrixTransform.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.10
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/webcamoid/src/webcamoid-9.1.1/libAvKys/Plugins/MatrixTransform/share/qml/main.qml
  0x0,0x0,0x3,0xa3,
  0x0,
  0x0,0xd,0xe9,0x78,0x9c,0xd5,0x54,0x5d,0x93,0xda,0x36,0x14,0x7d,0xf7,0xaf,0xb8,
  0x93,0x27,0x48,0x89,0xcd,0x47,0xb6,0xf,0x4e,0xda,0xe,0x61,0x60,0xc3,0x94,0xfd,
  0x88,0x61,0xbb,0x65,0x92,0x4c,0x47,0xd8,0x17,0xac,0x59,0x23,0x39,0x92,0xc,0x38,
  0xcd,0xfe,0xf7,0x5e,0xd9,0x8b,0x17,0x36,0x3b,0x69,0xcb,0xc,0xf,0xe8,0xc1,0x63,
  0x49,0xf7,0x1e,0x9d,0x7b,0xce,0x95,0xbc,0x97,0x70,0x8b,0xb3,0x90,0x2d,0x25,0x8f,
  0x1a,0xb0,0x2e,0x7e,0x21,0x64,0xa9,0xc9,0x14,0x2,0x4b,0xd3,0x84,0x87,0xcc,0x70,
  0x29,0x5c,0x7,0x5e,0x42,0x4f,0xa6,0xb9,0xe2,0x8b,0xd8,0x40,0xad,0x57,0x87,0x76,
  0xb3,0xf5,0x33,0xc0,0xb9,0x14,0x5f,0x59,0x22,0xa1,0xbf,0xc1,0x2f,0x19,0xc7,0x4,
  0xae,0x31,0x92,0x2,0x29,0xdc,0x66,0x54,0xd8,0xc0,0x35,0xcc,0x15,0x22,0x68,0x39,
  0x37,0x6b,0xa6,0xd0,0x87,0x5c,0x66,0x74,0x92,0x0,0x85,0x11,0xd7,0x46,0xf1,0x59,
  0x66,0x10,0xb8,0x1,0x26,0x22,0x4f,0x2a,0x58,0xca,0x88,0xcf,0x73,0xb,0x42,0x6b,
  0x99,0x88,0x50,0x81,0x89,0x11,0xc,0xaa,0xa5,0x6,0x39,0x2f,0x26,0xe7,0x97,0x37,
  0x70,0x8e,0x2,0x15,0xa3,0x73,0xb3,0x19,0x91,0x85,0x11,0xf,0x51,0x68,0xe2,0xae,
  0x21,0xb5,0x2b,0x3a,0xc6,0x8,0x66,0x5,0x8e,0xcd,0x18,0x58,0xe,0xe3,0x7,0xe,
  0x30,0x90,0x4,0x5c,0xd4,0xd7,0x0,0xe4,0xb4,0xaf,0x60,0x85,0x4a,0xd3,0x1c,0x3a,
  0xdb,0x33,0x1e,0x0,0x1b,0x20,0x95,0x5,0xa9,0x31,0x63,0x99,0x2b,0x90,0xa9,0xcd,
  0xab,0x13,0xdd,0x1c,0x12,0x66,0x1e,0x53,0xdd,0xe7,0x6a,0x7f,0x2c,0x91,0xa6,0xa2,
  0x0,0x8e,0x65,0x4a,0xe5,0xc4,0x84,0x47,0x5,0xae,0x79,0x92,0xc0,0xc,0x21,0xd3,
  0x38,0xcf,0x92,0x86,0xcd,0xa7,0x60,0xb8,0x1d,0x4e,0xde,0x5f,0xdd,0x4c,0xa0,0x7b,
  0x39,0x85,0xdb,0x6e,0x10,0x74,0x2f,0x27,0xd3,0x37,0x14,0x6c,0x62,0x49,0xbb,0xb8,
  0xc2,0x12,0x8a,0x2f,0xc9,0x28,0x42,0xa6,0xa2,0x14,0x13,0x26,0x27,0xee,0x16,0xe1,
  0xa2,0x1f,0xf4,0xde,0x53,0x4a,0xf7,0xdd,0x70,0x34,0x9c,0x4c,0xa9,0x2,0x18,0xc,
  0x27,0x97,0xfd,0xf1,0x18,0x6,0x57,0x1,0x74,0xe1,0xba,0x1b,0x4c,0x86,0xbd,0x9b,
  0x51,0x37,0x80,0xeb,0x9b,0xe0,0xfa,0x6a,0xdc,0x77,0x1,0xc6,0x68,0x69,0x59,0x7,
  0x7f,0xa4,0xef,0xbc,0xb0,0x88,0x34,0x8c,0xd0,0x30,0x9e,0xe8,0x6d,0xd5,0x53,0x72,
  0x55,0x13,0xbb,0x24,0x82,0x98,0xad,0x90,0xdc,0xd,0x91,0xaf,0x88,0x1b,0x83,0x90,
  0xda,0xe7,0xdf,0x9d,0xb3,0x20,0xd4,0x50,0x62,0x51,0x94,0xf9,0xa8,0xa2,0xb,0xc3,
  0x39,0x8,0x69,0x1a,0xa0,0x89,0xe0,0xdb,0xd8,0x98,0xd4,0xf7,0xbc,0xf5,0x7a,0xed,
  0x2e,0x44,0xe6,0x4a,0xb5,0xf0,0x92,0x12,0x40,0x7b,0xbf,0xee,0x58,0xf0,0x6a,0xcc,
  0xd,0x35,0xdb,0x36,0xbc,0x42,0x5b,0x10,0x78,0x36,0x73,0xb9,0xf4,0x28,0xd0,0x73,
  0x1c,0x92,0x50,0x2a,0x3,0x1f,0xcc,0x87,0x8c,0x87,0x77,0xd0,0x76,0x5b,0xed,0x27,
  0x6b,0x6e,0x4f,0xa,0xa3,0x64,0xa2,0x69,0xf3,0xec,0xe9,0xde,0x88,0x51,0x53,0x18,
  0xd,0x2d,0xb7,0xe3,0x38,0x3d,0x99,0x64,0x4b,0x51,0x2e,0xc1,0xdf,0xe,0xd0,0x48,
  0x15,0xb9,0xad,0xc8,0x19,0x2e,0xc,0x84,0x98,0x24,0x63,0xfe,0x95,0x68,0x9d,0x35,
  0x9d,0x62,0x7b,0x9e,0x89,0xd0,0xb6,0x13,0x64,0x29,0xf5,0x23,0xfe,0x8e,0x4a,0x60,
  0x52,0xe3,0xd4,0xf5,0x9b,0x6,0xac,0x58,0x92,0x61,0xbd,0x88,0x2b,0xc1,0xec,0x58,
  0x31,0x5,0x77,0x45,0x18,0xfc,0x2,0x17,0x8c,0x9a,0x6b,0x33,0x21,0xef,0x35,0xf9,
  0xb2,0x74,0xcb,0x8d,0x2a,0xb6,0x9c,0x7e,0x2c,0xe0,0x3e,0x53,0x78,0x1,0x58,0xed,
  0x3e,0x9f,0x4c,0x61,0x3b,0x28,0xf7,0x25,0xcd,0x11,0x9b,0xd1,0xce,0x23,0x9,0xcf,
  0x2b,0x95,0xd5,0x24,0x2d,0xa,0x77,0xcd,0xef,0x78,0x4a,0xb7,0x99,0x15,0x76,0xd8,
  0x99,0x57,0xc1,0x16,0xb7,0xec,0xaf,0x65,0x71,0x56,0x95,0x6f,0x70,0x63,0x7c,0xf8,
  0xa2,0x27,0xaa,0xf6,0xa2,0x8a,0x84,0x32,0xe8,0x45,0xfd,0xe1,0x64,0xfb,0x3d,0x57,
  0x3c,0xda,0xd3,0xd3,0x8e,0xb0,0x90,0x59,0xfb,0xd0,0x71,0x76,0x18,0xc1,0x9f,0xc0,
  0x36,0x5c,0x57,0x2b,0x13,0x3a,0x63,0x40,0xf,0x53,0xb4,0x93,0x69,0x7,0x8f,0x7c,
  0xd8,0x6c,0xf6,0x96,0xca,0x13,0xdc,0x54,0xe1,0x1c,0x15,0x3d,0x4b,0xb7,0x3c,0x32,
  0xb1,0x5f,0xd9,0xb5,0x17,0x5b,0x52,0x7f,0x5e,0xbb,0x8f,0xcd,0xcf,0x7b,0xb1,0x1a,
  0x13,0xc,0xcd,0xbb,0xfc,0x42,0xd2,0xf5,0xf6,0xc1,0xa8,0x6c,0x1f,0x8b,0xfc,0xe0,
  0x64,0xbb,0x54,0x3e,0x4,0xb8,0xe8,0x6f,0xd2,0x3f,0xb6,0xb,0x4f,0x38,0xdb,0xa1,
  0x8a,0x8,0x1f,0xbc,0x57,0xbf,0xd5,0x3e,0x45,0x3f,0x7d,0x72,0xe9,0xf3,0xad,0xf8,
  0xf9,0x56,0xfd,0xd7,0xbd,0xbd,0xb4,0xfb,0xbd,0x59,0x37,0xc,0x51,0x6b,0x3e,0x4b,
  0xd0,0x15,0x6c,0x89,0x5b,0xfd,0xcb,0xa6,0x85,0x66,0x3,0x2,0xb9,0x86,0x26,0xc9,
  0xbf,0x97,0x25,0x85,0x15,0xb2,0x17,0x33,0xb1,0x40,0x52,0x6e,0xaf,0x4f,0x29,0xc7,
  0xca,0x51,0x77,0xbe,0x3f,0xf0,0x87,0xea,0xe7,0xc7,0x51,0xbf,0x75,0xba,0xea,0xb7,
  0xe,0x50,0xbf,0x75,0xa0,0xfa,0xcd,0xe3,0xa8,0xdf,0x3e,0x5d,0xf5,0xdb,0x7,0xa8,
  0xdf,0xfe,0x5e,0xfd,0xdd,0xc7,0x68,0xfa,0xdf,0x1f,0xa3,0xfc,0x48,0x8f,0x51,0xe7,
  0x74,0xd,0x79,0x78,0x8c,0x5a,0xff,0xc7,0x90,0xce,0x61,0xd7,0x21,0x3f,0xd2,0x63,
  0xf4,0xfa,0x74,0xd5,0x6f,0x1d,0xa0,0xfe,0xeb,0x3,0xd5,0x3f,0xd2,0x63,0x74,0x76,
  0xba,0xea,0xb7,0xf,0x50,0xff,0xec,0x79,0xf5,0xef,0x9d,0x7b,0xe7,0x1f,0x8b,0xd,
  0xfe,0xda,
  
};

static const unsigned char qt_resource_name[] = {
  // MatrixTransform
  0x0,0xf,
  0x3,0x79,0x2f,0xad,
  0x0,0x4d,
  0x0,0x61,0x0,0x74,0x0,0x72,0x0,0x69,0x0,0x78,0x0,0x54,0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,0x6d,
    // share
  0x0,0x5,
  0x0,0x79,0xe8,0x85,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // main.qml
  0x0,0x8,
  0x8,0x1,0x5a,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/MatrixTransform
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/MatrixTransform/share
  0x0,0x0,0x0,0x24,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/MatrixTransform/share/qml
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/MatrixTransform/share/qml/main.qml
  0x0,0x0,0x0,0x40,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_MatrixTransform)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_MatrixTransform)(); }
   } dummy;
}
